@@ -5,6 +5,6 @@
       <h2<?php print $title_attributes; ?>><?php print $block->subject; ?></h2>
     <?php endif; ?>
     <?php print render($title_suffix); ?>
-    <div class="menu-wrapper clearfix"><?php print $content ?></div>
+    <?php print $content ?>
   </nav>
 <?php endif; ?>
